Mixed-Up Code Questions
-----------------------

.. selectquestion:: re_mixed1_sq
   :fromid: re_mixed1, re_mixed1_ac
   :toggle:


.. selectquestion:: re_mixed2_sq
   :fromid: re_mixed2, re_mixed2_ac
   :toggle:


.. selectquestion:: re_mixed3_sq
   :fromid: re_mixed3, re_mixed3_ac
   :toggle:


.. selectquestion:: re_mixed4_v2_sq
   :fromid: re_mixed4_v2, re_mixed4_v2_ac
   :toggle:


.. selectquestion:: re_mixed5_v2_sq
   :fromid: re_mixed5_v2, re_mixed5_ac
   :toggle:


.. selectquestion:: re_mixed6_v2_sq
   :fromid: re_mixed6_v2, re_mixed6_ac
   :toggle:


.. selectquestion:: re_mixed7_v2_sq
   :fromid: re_mixed7_v2, re_mixed7_ac
   :toggle:


.. selectquestion:: re_mixed8_sq
   :fromid: re_mixed8, re_mixed8_ac
   :toggle:


.. selectquestion:: re_mixed9_v2_sq
   :fromid: re_mixed9_v2, re_mixed9_ac
   :toggle:


.. selectquestion:: re_mixed10_v2_sq
   :fromid: re_mixed10_v2, re_mixed10_ac
   :toggle:
